.. HDX Python API documentation master file.

HDX Python Scraper Documentation
================================

The HDX Python Scraper Library is designed to enable you to easily develop code that assembles data from one or more
sources.

Contents
--------

.. toctree::
   :maxdepth: 1

   source/hdx.rst
   source/hdx.scraper.rst

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
